@@ -8,8 +8,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_PRECOMMANDJOB_H
-#define MAILTRANSPORT_PRECOMMANDJOB_H
+#pragma once
 
 #include "mailtransport_export.h"
 
@@ -17,7 +16,8 @@
 
 class PreCommandJobPrivate;
 
-namespace MailTransport {
+namespace MailTransport
+{
 /**
   Job to execute a command.
   This is used often for sending or receiving mails, for example to set up
@@ -50,7 +50,6 @@ public:
     void start() override;
 
 protected:
-
     /**
       Reimplemented from KJob.
     */
@@ -62,4 +61,3 @@ private:
 };
 } // namespace MailTransport
 
-#endif // MAILTRANSPORT_PRECOMMANDJOB_H
