@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_TRANSPORT_H
-#define MAILTRANSPORT_TRANSPORT_H
+#pragma once
 
 #include <mailtransport_export.h>
 #include <transportbase.h>
@@ -40,7 +39,7 @@ public:
     */
     ~Transport() override;
 
-    typedef QList<Transport *> List;
+    using List = QList<Transport *>;
 
     /**
       Returns true if this transport is valid, ie. has all necessary data set.
@@ -147,4 +146,3 @@ private:
 };
 } // namespace MailTransport
 
-#endif // MAILTRANSPORT_TRANSPORT_H
