@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_DISPATCHERINTERFACE_H
-#define MAILTRANSPORT_DISPATCHERINTERFACE_H
+#pragma once
 
 #include <mailtransportakonadi_export.h>
 
@@ -64,4 +63,3 @@ public:
 };
 } // namespace MailTransport
 
-#endif // MAILTRANSPORT_DISPATCHERINTERFACE_H
